@@ -7,8 +7,8 @@ from svc_infra.api.fastapi.dual import (
 from svc_infra.api.fastapi.openapi.models import APIVersionSpec, ServiceInfo
 
 from .cache.add import setup_caching
-from .deps import Require
 from .ease import easy_service_api, easy_service_app
+from .pagination import cursor_window, sort_by, text_filter, use_pagination
 from .setup import setup_service_api
 
 __all__ = [
@@ -18,10 +18,14 @@ __all__ = [
     "dualize_protected",
     "ServiceInfo",
     "APIVersionSpec",
-    "Require",
     # Ease
     "setup_service_api",
     "easy_service_api",
     "easy_service_app",
     "setup_caching",
+    # Pagination
+    "use_pagination",
+    "text_filter",
+    "sort_by",
+    "cursor_window",
 ]
