@@ -10,13 +10,6 @@ from .verify import verify_mfa_for_user
 
 
 def RequireMFAIfEnabled(body_field: str = "mfa"):
-    """
-    Requires MFA iff the current user has MFA enabled.
-    Looks for proof in the request body under `body_field` (e.g. "mfa"),
-    and falls back to query params ?mfa_code=&mfa_pre_token= for methods that
-    may not send bodies (e.g. DELETE).
-    """
-
     async def _dep(
         p: Identity,
         sess: SqlSessionDep,
@@ -25,8 +18,12 @@ def RequireMFAIfEnabled(body_field: str = "mfa"):
         mfa_pre_token: Optional[str] = Query(None, alias="mfa_pre_token"),
     ):
         proof = mfa or (
-            MFAProof(code=mfa_code, pre_token=mfa_pre_token) if mfa_code or mfa_pre_token else None
+            MFAProof(code=mfa_code, pre_token=mfa_pre_token)
+            if (mfa_code or mfa_pre_token)
+            else None
         )
+        if not getattr(p.user, "mfa_enabled", False):
+            return p
         res = await verify_mfa_for_user(
             user=p.user, session=sess, proof=proof, require_enabled=True
         )
