@@ -19,7 +19,7 @@ def set_auth_state(
 
 def get_auth_state() -> tuple[type, Callable[[], Any], str]:
     if _UserModel is None or _GetStrategy is None:
-        raise RuntimeError("Auth state not initialized; call set_auth_state() in add_auth().")
+        raise RuntimeError("Auth state not initialized; call set_auth_state() in add_auth_users().")
     return _UserModel, _GetStrategy, _AuthPrefix
 
 
