@@ -5,8 +5,11 @@ from svc_infra.cli.cmds.db.nosql.mongo.mongo_scaffold_cmds import (
 from svc_infra.cli.cmds.db.sql.alembic_cmds import register as register_alembic
 from svc_infra.cli.cmds.db.sql.sql_export_cmds import register as register_sql_export
 from svc_infra.cli.cmds.db.sql.sql_scaffold_cmds import register as register_sql_scaffold
+from svc_infra.cli.cmds.docs.docs_cmds import register as register_docs
+from svc_infra.cli.cmds.dx import register_dx
 from svc_infra.cli.cmds.jobs.jobs_cmds import app as jobs_app
 from svc_infra.cli.cmds.obs.obs_cmds import register as register_obs
+from svc_infra.cli.cmds.sdk.sdk_cmds import register as register_sdk
 
 from .help import _HELP
 
@@ -18,5 +21,8 @@ __all__ = [
     "register_mongo_scaffold",
     "register_obs",
     "jobs_app",
+    "register_sdk",
+    "register_dx",
+    "register_docs",
     "_HELP",
 ]
