@@ -23,6 +23,6 @@ Notes:
 * You can point `--project-root` at your Alembic root; if omitted we auto-detect.
 
 Learn more:
-* For full integration guides and all topics, run: `svc-infra docs list`
-* To explore docs commands, run: `svc-infra docs --help`
+* Explore available topics: `svc-infra docs --help`
+* Show a topic directly: `svc-infra docs <topic>` or `svc-infra docs show <topic>`
 """
